.. currentmodule:: kombu.compression

.. automodule:: kombu.compression

    .. contents::
        :local:

    Encoding/decoding
    -----------------

    .. autofunction:: compress
    .. autofunction:: decompress

    Registry
    --------

    .. autofunction:: encoders
    .. autofunction:: get_encoder
    .. autofunction:: get_decoder
    .. autofunction:: register
